@@ -34,8 +34,8 @@ else:
         soname = "libxcb.so"
 lib = ffi.dlopen(soname)
 
-__xcb_proto_version__ = "1.16.0"
-__version__ = "1.5.0"
+__xcb_proto_version__ = "1.17.0"
+__version__ = "1.8.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -83,7 +83,6 @@ def visualtype_to_c_struct(vt):
 
 
 class Unpacker(object):
-
     def __init__(self, known_max=None):
         self.size = 0
         self.offset = 0
@@ -131,7 +130,6 @@ class Unpacker(object):
 
 
 class CffiUnpacker(Unpacker):
-
     def __init__(self, cdata, known_max=None):
         self.cdata = cdata
         Unpacker.__init__(self, known_max)
@@ -151,7 +149,6 @@ class CffiUnpacker(Unpacker):
 
 
 class MemoryUnpacker(Unpacker):
-
     def __init__(self, buf):
         self.buf = buf
         Unpacker.__init__(self, len(self.buf))
@@ -169,40 +166,49 @@ class MemoryUnpacker(Unpacker):
 
 
 def popcount(n):
-    return bin(n).count('1')
+    return bin(n).count("1")
 
 
 class XcffibException(Exception):
+    """Generic XcbException; replaces xcb.Exception."""
 
-    """ Generic XcbException; replaces xcb.Exception. """
+    pass
+
+
+class XcffibNotImplemented(XcffibException, NotImplementedError):
     pass
 
 
 class ConnectionException(XcffibException):
     REASONS = {
         lib.XCB_CONN_ERROR: (
-            'xcb connection errors because of socket, '
-            'pipe and other stream errors.'),
+            "xcb connection errors because of socket, pipe and other stream errors."
+        ),
         lib.XCB_CONN_CLOSED_EXT_NOTSUPPORTED: (
-            'xcb connection shutdown because extension not supported'),
+            "xcb connection shutdown because extension not supported"
+        ),
         lib.XCB_CONN_CLOSED_MEM_INSUFFICIENT: (
-            'malloc(), calloc() and realloc() error upon failure, '
-            'for eg ENOMEM'),
+            "malloc(), calloc() and realloc() error upon failure, for eg ENOMEM"
+        ),
         lib.XCB_CONN_CLOSED_REQ_LEN_EXCEED: (
-            'Connection closed, exceeding request length that server '
-            'accepts.'),
+            "Connection closed, exceeding request length that server accepts."
+        ),
         lib.XCB_CONN_CLOSED_PARSE_ERR: (
-            'Connection closed, error during parsing display string.'),
+            "Connection closed, error during parsing display string."
+        ),
         lib.XCB_CONN_CLOSED_INVALID_SCREEN: (
-            'Connection closed because the server does not have a screen '
-            'matching the display.'),
+            "Connection closed because the server does not have a screen "
+            "matching the display."
+        ),
         lib.XCB_CONN_CLOSED_FDPASSING_FAILED: (
-            'Connection closed because some FD passing operation failed'),
+            "Connection closed because some FD passing operation failed"
+        ),
     }
 
     def __init__(self, err):
         XcffibException.__init__(
-            self, self.REASONS.get(err, "Unknown connection error."))
+            self, self.REASONS.get(err, "Unknown connection error.")
+        )
 
 
 class ProtocolException(XcffibException):
@@ -225,8 +231,7 @@ extensions = {}
 
 def _add_core(value, __setup, events, errors):
     if not issubclass(value, Extension):
-        raise XcffibException(
-            "Extension type not derived from xcffib.Extension")
+        raise XcffibException("Extension type not derived from xcffib.Extension")
     if not issubclass(__setup, Struct):
         raise XcffibException("Setup type not derived from xcffib.Struct")
 
@@ -243,19 +248,17 @@ def _add_core(value, __setup, events, errors):
 
 def _add_ext(key, value, events, errors):
     if not issubclass(value, Extension):
-        raise XcffibException(
-            "Extension type not derived from xcffib.Extension")
+        raise XcffibException("Extension type not derived from xcffib.Extension")
     extensions[key] = (value, events, errors)
 
 
 class ExtensionKey(object):
-
-    """ This definitely isn't needed, but we keep it around for compatibility
-    with xpyb.
-    """
-
     def __init__(self, name):
         self.name = name
+        self.c_key = ffi.new("struct xcb_extension_t *")
+        self.c_name = ffi.new("char[]", self.name.encode())
+        self.c_key.name = self.c_name
+        self.c_key.global_id = 0
 
     def __hash__(self):
         return hash(self.name)
@@ -266,19 +269,9 @@ class ExtensionKey(object):
     def __ne__(self, o):
         return self.name != o.name
 
-    def to_cffi(self):
-        c_key = ffi.new("struct xcb_extension_t *")
-        c_key.name = name = ffi.new('char[]', self.name.encode())
-        cffi_explicit_lifetimes[c_key] = name
-        # xpyb doesn't ever set global_id, which seems wrong, but whatever.
-        c_key.global_id = 0
-
-        return c_key
-
 
 class Protobj(object):
-
-    """ Note: Unlike xcb.Protobj, this does NOT implement the sequence
+    """Note: Unlike xcb.Protobj, this does NOT implement the sequence
     protocol. I found this behavior confusing: Protobj would implement the
     sequence protocol on self.buf, and then List would go and implement it on
     List.
@@ -333,7 +326,8 @@ class Cookie(object):
     def check(self):
         # Request is not void and checked.
         assert self.is_checked and self.reply_type is None, (
-            "Request is not void and checked")
+            "Request is not void and checked"
+        )
         self.conn.request_check(self.sequence)
 
     def discard_reply(self):
@@ -341,25 +335,22 @@ class Cookie(object):
 
 
 class VoidCookie(Cookie):
-
     def reply(self):
         raise XcffibException("No reply for this message type")
 
 
 class Extension(object):
-
     def __init__(self, conn, key=None):
         self.conn = conn
 
         if key is None:
             self.c_key = ffi.NULL
         else:
-            c_key = key.to_cffi()
-            cffi_explicit_lifetimes[self] = c_key
-            self.c_key = c_key
+            self.c_key = key.c_key
 
-    def send_request(self, opcode, data, cookie=VoidCookie, reply=None,
-                     is_checked=False):
+    def send_request(
+        self, opcode, data, cookie=VoidCookie, reply=None, is_checked=False
+    ):
         data = data.getvalue()
 
         assert len(data) > 3, "xcb_send_request data must be ast least 4 bytes"
@@ -379,7 +370,7 @@ class Extension(object):
 
         # Here we need this iov_base to keep this memory alive until the end of
         # the function.
-        xcb_parts[2].iov_base = iov_base = ffi.new('char[]', data)  # noqa
+        xcb_parts[2].iov_base = iov_base = ffi.new("char[]", data)  # noqa
         xcb_parts[2].iov_len = len(data)
         xcb_parts[3].iov_base = ffi.NULL
         xcb_parts[3].iov_len = -len(data) & 3  # is this really necessary?
@@ -392,10 +383,10 @@ class Extension(object):
 
     def __getattr__(self, name):
         if name.endswith("Checked"):
-            real = name[:-len("Checked")]
+            real = name[: -len("Checked")]
             is_checked = True
         elif name.endswith("Unchecked"):
-            real = name[:-len("Unchecked")]
+            real = name[: -len("Unchecked")]
             is_checked = False
         else:
             raise AttributeError(name)
@@ -406,9 +397,9 @@ class Extension(object):
 
 
 class List(Protobj):
-
     def __init__(self, unpacker, typ, count=None):
         Protobj.__init__(self, unpacker)
+        self.typ = typ
 
         self.list = []
         old = unpacker.offset
@@ -427,7 +418,7 @@ class List(Protobj):
 
         self.bufsize = unpacker.offset - old
 
-        self.raw = bytes(unpacker.buf[old:old + self.bufsize])
+        self.raw = bytes(unpacker.buf[old : old + self.bufsize])
 
         assert count is None or count == len(self.list)
 
@@ -449,21 +440,35 @@ class List(Protobj):
     def __delitem__(self, key):
         del self.list[key]
 
+    def __repr__(self):
+        # the spec uses both CHAR8 and VOID to indicate strings, we stringify
+        # both here. this is of course a heuristic, because it uses VOID to
+        # mean other things, but this just debug code, so it's probably fine...
+        if self.typ in ["c", "B"]:
+            return "\"" + self.to_string() + "\""
+        else:
+            return "[" + ", ".join(repr(i) for i in self) + "]"
+
     def to_string(self):
-        """ A helper for converting a List of chars to a native string. Dies if
+        """A helper for converting a List of chars to a native string. Dies if
         the list contents are not something that could be reasonably converted
-        to a string. """
+        to a string."""
         try:
-            return ''.join(chr(i[0]) for i in self)
+            return "".join(chr(i[0]) for i in self)
         except TypeError:
-            return ''.join(chr(i) for i in self)
+            return "".join(chr(i) for i in self)
+
+    def to_nullsep_string(self) -> list[str]:
+        """A helper for converting a List of chars to a list of native
+        strings, starting a new string each time a null (i.e. \\x00) is seen."""
+        return self.to_string().split("\x00")
 
     def to_utf8(self):
-        return b''.join(self).decode('utf-8')
+        return b"".join(self).decode("utf-8")
 
     def to_atoms(self):
-        """ A helper for converting a List of chars to an array of atoms """
-        return struct.unpack("<" + "%dI" % (len(self) // 4), b''.join(self))
+        """A helper for converting a List of chars to an array of atoms"""
+        return struct.unpack("<" + "%dI" % (len(self) // 4), b"".join(self))
 
     def buf(self):
         return self.raw
@@ -479,7 +484,6 @@ class List(Protobj):
 
 
 class OffsetMap(object):
-
     def __init__(self, core):
         self.offsets = [(0, 0, core)]
 
@@ -489,31 +493,35 @@ class OffsetMap(object):
 
     def get_extension_item(self, extension, item):
         try:
-            _, _, things = next((k, opcode, v) for k, opcode, v in self.offsets if opcode == extension)
+            _, _, things = next(
+                (k, opcode, v) for k, opcode, v in self.offsets if opcode == extension
+            )
             return things[item]
         except StopIteration:
             raise IndexError(item)
 
     def __getitem__(self, item):
         try:
-            offset, _, things = next((k, opcode, v) for k, opcode, v in self.offsets if item >= k)
+            offset, _, things = next(
+                (k, opcode, v) for k, opcode, v in self.offsets if item >= k
+            )
             return things[item - offset]
         except StopIteration:
             raise IndexError(item)
 
 
 class Connection(object):
+    """`auth` here should be '<name>:<data>', a format bequeathed to us from
+    xpyb."""
 
-    """ `auth` here should be '<name>:<data>', a format bequeathed to us from
-    xpyb. """
     def __init__(self, display=None, fd=-1, auth=None):
         if auth is not None:
-            [name, data] = auth.split(b':')
+            [name, data] = auth.split(b":")
 
             c_auth = ffi.new("xcb_auth_info_t *")
-            c_auth.name = ffi.new('char[]', name)
+            c_auth.name = ffi.new("char[]", name)
             c_auth.namelen = len(name)
-            c_auth.data = ffi.new('char[]', data)
+            c_auth.data = ffi.new("char[]", data)
             c_auth.datalen = len(data)
         else:
             c_auth = ffi.NULL
@@ -521,7 +529,7 @@ class Connection(object):
         if display is None:
             display = ffi.NULL
         else:
-            display = display.encode('latin1')
+            display = display.encode("latin1")
 
         i = ffi.new("int *")
 
@@ -537,8 +545,9 @@ class Connection(object):
 
     def _init_x(self):
         if core is None:
-            raise XcffibException("No core protocol object has been set.  "
-                                  "Did you import xcffib.xproto?")
+            raise XcffibException(
+                "No core protocol object has been set.  Did you import xcffib.xproto?"
+            )
 
         self.core = core(self)
         self.setup = self.get_setup()
@@ -549,10 +558,14 @@ class Connection(object):
 
     def _setup_extensions(self):
         for key, (_, events, errors) in extensions.items():
-            # We're explicitly not putting this as an argument to the next call
-            # as a hack for lifetime management.
-            c_ext = key.to_cffi()
-            reply = lib.xcb_get_extension_data(self._conn, c_ext)
+            reply = lib.xcb_get_extension_data(self._conn, key.c_key)
+            # although it does not say so in the man page,
+            # xcb_get_extension_data() will return NULL if the connection has
+            # an error. let's guard against this, and do our own connection
+            # checking in this case.
+            if reply == ffi.NULL:
+                self.invalid()
+                raise XcffibException("uh oh... connection valid but xcb_get_extension_data() returned NULL?")
             self._event_offsets.add(reply.first_event, reply.major_opcode, events)
             self._error_offsets.add(reply.first_error, reply.major_opcode, errors)
 
@@ -571,6 +584,7 @@ class Connection(object):
         Check that the connection is valid both before and
         after the function is invoked.
         """
+
         @functools.wraps(f)
         def wrapper(*args):
             self = args[0]
@@ -579,6 +593,7 @@ class Connection(object):
                 return f(*args)
             finally:
                 self.invalid()
+
         return wrapper
 
     @ensure_connected
@@ -689,7 +704,7 @@ class Connection(object):
         self._process_error(err)
 
     def hoist_event(self, e):
-        """ Hoist an xcb_generic_event_t to the right xcffib structure. """
+        """Hoist an xcb_generic_event_t to the right xcffib structure."""
         if e.response_type == 0:
             return self._process_error(ffi.cast("xcb_generic_error_t *", e))
 
@@ -697,7 +712,7 @@ class Connection(object):
         # this bit set. We don't actually care where the event came from, so we
         # just throw this away. Maybe we could expose this, if anyone actually
         # cares about it.
-        response_type = e.response_type & 0x7f
+        response_type = e.response_type & 0x7F
 
         buf = CffiUnpacker(e)
         event = None
@@ -733,7 +748,6 @@ connect = Connection
 
 
 class Response(Protobj):
-
     def __init__(self, unpacker):
         Protobj.__init__(self, unpacker)
 
@@ -754,7 +768,6 @@ class Response(Protobj):
 
 
 class Reply(Response):
-
     def __init__(self, unpacker):
         Response.__init__(self, unpacker)
 
@@ -764,7 +777,6 @@ class Reply(Response):
 
 
 class Event(Response):
-
     def __init__(self, unpacker):
         # This is here for debugging purposes!
         self.unpacker = unpacker
@@ -773,11 +785,12 @@ class Event(Response):
 
         # If this is a xcb_ge_generic_event_t (response type 35) then we need a few more fields
         if self.xge and isinstance(unpacker, CffiUnpacker):
-            self.extension, self.length, self.event_type, self.full_sequence = unpacker.unpack("xB2xIH22xI")
+            self.extension, self.length, self.event_type, self.full_sequence = (
+                unpacker.unpack("xB2xIH22xI")
+            )
 
             # There's some extra work to do if the event has data past the 32 byte boundary
             if self.length:
-
                 # Calculate the size of the original buffer. This is 4 bytes short as it seems to omit the `full_sequence` field
                 buffer_size = 32 + (self.length * 4) + 4
 
@@ -785,7 +798,7 @@ class Event(Response):
                 buffer = ffi.buffer(unpacker.cdata, buffer_size)
 
                 # Copy the event to the new buffer and skip the `full_sequence` field
-                buffer[32:buffer_size - 5] = buffer[36: buffer_size - 1]
+                buffer[32 : buffer_size - 5] = buffer[36 : buffer_size - 1]
 
                 # Provide the resized buffer to the unpacker
                 unpacker.buf = buffer
@@ -796,15 +809,14 @@ class Event(Response):
 
 
 class Error(Response, XcffibException):
-
     def __init__(self, unpacker):
         Response.__init__(self, unpacker)
         XcffibException.__init__(self)
-        self.code = unpacker.unpack('B', increment=False)
+        self.code = unpacker.unpack("B", increment=False)
 
 
 def pack_list(from_, pack_type):
-    """ Return the wire packed version of `from_`. `pack_type` should be some
+    """Return the wire packed version of `from_`. `pack_type` should be some
     subclass of `xcffib.Struct`, or a string that can be passed to
     `struct.pack`. You must pass `size` if `pack_type` is a struct.pack string.
     """
@@ -812,7 +824,7 @@ def pack_list(from_, pack_type):
     if len(from_) == 0:
         return bytes()
 
-    if pack_type == 'c':
+    if pack_type == "c":
         if isinstance(from_, bytes):
             # Catch Python 3 bytes and Python 2 strings
             # PY3 is "helpful" in that when you do tuple(b'foo') you get
@@ -823,7 +835,7 @@ def pack_list(from_, pack_type):
             # Catch Python 3 strings and Python 2 unicode strings, both of
             # which we encode to bytes as utf-8
             # Here we create the tuple of bytes from the encoded string
-            from_ = [bytes((b,)) for b in bytearray(from_, 'utf-8')]
+            from_ = [bytes((b,)) for b in bytearray(from_, "utf-8")]
         elif isinstance(from_[0], int):
             # Pack from_ as char array, where from_ may be an array of ints
             # possibly greater than 256
@@ -831,6 +843,7 @@ def pack_list(from_, pack_type):
                 for _ in range(4):
                     v, r = divmod(v, 256)
                     yield r
+
             from_ = [bytes((b,)) for i in from_ for b in to_bytes(i)]
 
     if isinstance(pack_type, str):
@@ -849,7 +862,7 @@ def pack_list(from_, pack_type):
 
 
 def wrap(ptr):
-    c_conn = ffi.cast('xcb_connection_t *', ptr)
+    c_conn = ffi.cast("xcb_connection_t *", ptr)
     conn = Connection.__new__(Connection)
     conn._conn = c_conn
     conn._init_x()
