@@ -1,6 +1,8 @@
 import xcffib
 import struct
-import six
+import io
+from dataclasses import dataclass
+
 MAJOR_VERSION = 1
 MINOR_VERSION = 0
 key = xcffib.ExtensionKey("Generic Event Extension")
@@ -8,35 +10,30 @@ _events = {}
 _errors = {}
 
 
+@dataclass(init=False)
 class QueryVersionReply(xcffib.Reply):
+    xge = False
 
     def __init__(self, unpacker):
+        if isinstance(unpacker, xcffib.Protobj):
+            unpacker = xcffib.MemoryUnpacker(unpacker.pack())
         xcffib.Reply.__init__(self, unpacker)
         base = unpacker.offset
         self.major_version, self.minor_version = unpacker.unpack("xx2x4xHH20x")
         self.bufsize = unpacker.offset - base
 
 
+@dataclass(init=False)
 class QueryVersionCookie(xcffib.Cookie):
     reply_type = QueryVersionReply
 
 
+@dataclass(init=False)
 class geExtension(xcffib.Extension):
+    def QueryVersion(self, client_major_version, client_minor_version, is_checked=True):
+        buf = io.BytesIO()
+        buf.write(struct.pack("=xx2xHH", client_major_version, client_minor_version))
+        return self.send_request(0, buf, QueryVersionCookie, is_checked=is_checked)
+
 
-    def QueryVersion(
-            self,
-            client_major_version,
-            client_minor_version,
-            is_checked=True):
-        buf = six.BytesIO()
-        buf.write(
-            struct.pack(
-                "=xx2xHH",
-                client_major_version,
-                client_minor_version))
-        return self.send_request(
-            0,
-            buf,
-            QueryVersionCookie,
-            is_checked=is_checked)
 xcffib._add_ext(key, geExtension, _events, _errors)
